; Macros for *LISP control forms which suppress execution of branches
; with no processors selected

; Copyright (c) Syracuse University, all rights reserved

(in-package '*LISP)         ; for safety

; General test for live processors

(defmacro live (&rest body)
"(live <pexpr> <pexpr> ...) -- evaluate pexpr's if CSS not empty"
 `(when (*or t!!) . ,body)
)

; Alternate for *if

(defmacro *if* (test ifx &optional (thenx nil thp))
"(*if* <ptest> <if-expr> { <then-expr> } ) -- like *if unless CSS empty"
 (list* '*if test (list 'live ifx) (if thp (list (list 'live thenx)) nil))
)

; Internal function for cond's

(defun cond*body (clause)
 (let ((test (car clause)) (rest (cdr clause)))
   (cons test (if rest (list (cons 'live rest)) nil)))
)

; Alternate for *cond

(defmacro *cond* (&rest clauses)
"(*cond* (<ptest> <pexpr> ...) ...) -- like *cond unless CSS empty" 
 (cons '*cond (mapcar #'cond*body clauses))
)

; Alternate for *when

(defmacro *when* (test &rest body)
"(*when* <ptest> <pexpr> <pexpr> ...) -- like *when unless CSS empty"
 `(*when ,test (when (*or t!!) . ,body))
)
